package com.ff.common.mapper;

import java.math.BigDecimal;
import java.util.List;
import com.ff.common.domain.TenantGameQuotaFlow;

/**
 * 租户游戏额度流水Mapper接口
 * 
 * @author shi
 * @date 2025-02-12
 */
public interface TenantGameQuotaFlowMapper 
{
    /**
     * 查询租户游戏额度流水
     * 
     * @param id 租户游戏额度流水主键
     * @return 租户游戏额度流水
     */
     TenantGameQuotaFlow selectTenantGameQuotaFlowById(Long id);

    /**
     * 查询租户游戏额度流水列表
     * 
     * @param tenantGameQuotaFlow 租户游戏额度流水
     * @return 租户游戏额度流水集合
     */
     List<TenantGameQuotaFlow> selectTenantGameQuotaFlowList(TenantGameQuotaFlow tenantGameQuotaFlow);

    /**
     * 新增租户游戏额度流水
     * 
     * @param tenantGameQuotaFlow 租户游戏额度流水
     * @return 结果
     */
     int insertTenantGameQuotaFlow(TenantGameQuotaFlow tenantGameQuotaFlow);

    /**
     * 修改租户游戏额度流水
     * 
     * @param tenantGameQuotaFlow 租户游戏额度流水
     * @return 结果
     */
     int updateTenantGameQuotaFlow(TenantGameQuotaFlow tenantGameQuotaFlow);

    /**
     * 删除租户游戏额度流水
     * 
     * @param id 租户游戏额度流水主键
     * @return 结果
     */
     int deleteTenantGameQuotaFlowById(Long id);

    /**
     * 批量删除租户游戏额度流水
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteTenantGameQuotaFlowByIds(Long[] ids);


    /**
     * 通过会员id获取余额
     *
     * @param tenantGameQuotaFlow 租户游戏配额流
     * @return {@link BigDecimal }
     */
    BigDecimal getBalanceByMemberId(TenantGameQuotaFlow tenantGameQuotaFlow);
}
